@@ -1,12 +1,12 @@
 #
-# Copyright (C) 2015 Joel Maslak
+# Copyright (C) 2015,2016 J. Maslak
 # All Rights Reserved - See License
 #
 
 use v5.8;
 
 package Term::Tmux::Layout;
-$Term::Tmux::Layout::VERSION = '1.004';
+$Term::Tmux::Layout::VERSION = '1.005';
 # ABSTRACT: Create tmux layout strings programmatically
 
 use strict;
@@ -395,7 +395,7 @@ Term::Tmux::Layout - Create tmux layout strings programmatically
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -533,11 +533,11 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Term-Layout>
 
 =head1 AUTHOR
 
-Joel Maslak <jmaslak@antelope.net>
+J. Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Joel Maslak.
+This software is copyright (c) 2015-2016 by J. Maslak.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
